ClockHealth

Enum ClockHealth 

pub enum ClockHealth {
    Healthy,
    Degraded {
        drift_ms: u64,
    },
    Critical {
        drift_ms: u64,
    },
}
Health status of the HLC clock.

Variants



Healthy

Clock drift is within normal bounds (<100ms).



Degraded

Clock drift is elevated but acceptable (100ms - 1s).

Fields

drift_ms: u64


Critical

Clock drift is critical (>1s) - indicates NTP failure or partition.

Fields

drift_ms: u64

Implementations

Source

impl ClockHealth

pub const fn is_healthy(&self) -> bool

Check if the clock is in a healthy state.

pub const fn is_critical(&self) -> bool

Check if the clock is in a critical state.