parse_header

Function parse_header 

pub fn parse_header(data: &[u8]) -> Result<Header>
Parse a TLV header from a byte slice.

Returns the parsed header or an error if the buffer is too small or contains invalid data.

Errors

Returns an error if the buffer is too small for the header.