NumaAlignedBuffer

Struct NumaAlignedBuffer 

pub struct NumaAlignedBuffer { /* private fields */ }

Implementations

Source

impl NumaAlignedBuffer

pub fn new(capacity: usize, numa_node: usize) -> Result<Self>

Create a new NUMA-aligned buffer.

Errors

Returns an error if NUMA allocation fails.

pub fn numa_node(&self) -> usize

pub fn as_ptr(&self) -> *const u8

pub fn as_mut_ptr(&mut self) -> *mut u8

pub fn as_slice(&self) -> &[u8]

pub fn as_mut_slice(&mut self) -> &mut [u8]

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn capacity(&self) -> usize

pub fn set_len(&mut self, len: usize)

pub fn write(&mut self, offset: usize, data: &[u8]) -> Result<()>

Write data at the specified offset.

Errors

Returns an error if write exceeds buffer capacity.

pub fn clear(&mut self)

pub fn mlock(&self) -> Result<()>

Lock the buffer in memory using mlock to prevent page faults.

Errors

Returns an error if mlock fails.

pub fn prefault(&mut self)

Prefault all pages in the buffer by touching each page.

pub fn lock_and_prefault(&mut self) -> Result<()>

Lock and prefault the buffer for zero-latency access on hot path.

Errors

Returns an error if mlock fails.